# SusDesign
![](Galactus.png)

Данная утилита создана для курса System design.

Это первый прототип, так что все очень криво. Людей с ровными руками приветствую сделать MR.

## Как начать

````
pip install susdes
susdes setup
````

## Что можно

Вывести текущие дз: 

````
susdes homework list
````

Посмотреть на **свои** посылки (определяется по ФИО):

````
susdes homework stat HOMEWORK
````

Загрузить решение в систему:
````
susdes homework submit HOMEWORK
````
Примечание: перед запуском нужно закомитить все изменения, коммит определится автоматически.
